summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-12-21 17:08:46 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-12-21 17:12:39 -0600
commit10569a452f8f8bce0300c0cd5ad71374b6512417 (patch)
tree447d3eac376be6c9b01a69bc246bdc26e9cd8a7e
parentdc294204b641373bc6eb603075a8b98f51a75dd8 (diff)
downloadlibpng-10569a452f8f8bce0300c0cd5ad71374b6512417.tar.gz
[libpng16] Imported from libpng-1.6.16rc03.tarv1.6.16rc03
-rw-r--r--CMakeLists.txt2
-rw-r--r--LICENSE2
-rw-r--r--README2
-rw-r--r--configure.ac4
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.312
-rw-r--r--libpngpf.32
-rw-r--r--png.c6
-rw-r--r--png.h16
-rw-r--r--pngconf.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt10
-rw-r--r--scripts/def.c2
-rw-r--r--scripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt4
-rw-r--r--scripts/symbols.def2
22 files changed, 44 insertions, 44 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 4ea0492e0..84f597416 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -253,7 +253,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 16.${PNGLIB_RELEASE}.1.6.16rc02
+# VERSION 16.${PNGLIB_RELEASE}.1.6.16rc03
VERSION 16.${PNGLIB_RELEASE}.0
SOVERSION 16
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index 35a7873b8..5531c6ad3 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.16rc02, December 21, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.16rc03, December 21, 2014, are
Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
diff --git a/README b/README
index 78847166d..45484c93b 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.16rc02 - December 21, 2014 (shared library 16.0)
+README for libpng version 1.6.16rc03 - December 21, 2014 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure.ac b/configure.ac
index 386145b49..7ef8b6517 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,7 +18,7 @@ AC_PREREQ([2.68])
dnl Version number stuff here:
-AC_INIT([libpng],[1.6.16rc02],[png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng],[1.6.16rc03],[png-mng-implement@lists.sourceforge.net])
AC_CONFIG_MACRO_DIR([scripts])
# libpng does not follow GNU file name conventions (hence 'foreign')
@@ -39,7 +39,7 @@ dnl automake, so the following is not necessary (and is not defined anyway):
dnl AM_PREREQ([1.11.2])
dnl stop configure from automagically running automake
-PNGLIB_VERSION=1.6.16rc02
+PNGLIB_VERSION=1.6.16rc03
PNGLIB_MAJOR=1
PNGLIB_MINOR=6
PNGLIB_RELEASE=16
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 165a4dd2e..4d10796ec 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.16rc02 - December 21, 2014
+ libpng version 1.6.16rc03 - December 21, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.16rc02 - December 21, 2014
+ libpng versions 0.97, January 1998, through 1.6.16rc03 - December 21, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -5280,7 +5280,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.16rc02 are Y2K compliant. It is my belief that earlier
+upward through 1.6.16rc03 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
diff --git a/libpng.3 b/libpng.3
index bcb2371c5..02e42627c 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
.TH LIBPNG 3 "December 21, 2014"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.16rc02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.16rc03
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -504,7 +504,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.16rc02 - December 21, 2014
+ libpng version 1.6.16rc03 - December 21, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -515,7 +515,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.16rc02 - December 21, 2014
+ libpng versions 0.97, January 1998, through 1.6.16rc03 - December 21, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -5784,7 +5784,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.16rc02 are Y2K compliant. It is my belief that earlier
+upward through 1.6.16rc03 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -6091,7 +6091,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.16rc02 - December 21, 2014:
+Libpng version 1.6.16rc03 - December 21, 2014:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6114,7 +6114,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.16rc02, December 21, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.16rc03, December 21, 2014, are
Copyright (c) 2004,2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
diff --git a/libpngpf.3 b/libpngpf.3
index 2b4b90644..2cbce6bca 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
.TH LIBPNGPF 3 "December 21, 2014"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.16rc02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.16rc03
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.c b/png.c
index 4e359fc5c..ea5bd4105 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_16rc02 Your_png_h_is_not_version_1_6_16rc02;
+typedef png_libpng_version_1_6_16rc03 Your_png_h_is_not_version_1_6_16rc03;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -769,13 +769,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.16rc02 - December 21, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.6.16rc03 - December 21, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.16rc02 - December 21, 2014\
+ return "libpng version 1.6.16rc03 - December 21, 2014\
Copyright (c) 1998-2014 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index d2f15fc56..d65951205 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.16rc02,December 21, 2014
+ * libpng version 1.6.16rc03,December 21, 2014
*
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 3e8037817..1d317e3c8 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -2008,4 +2008,4 @@ main(void)
#endif
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_16rc02 Your_png_h_is_not_version_1_6_16rc02;
+typedef png_libpng_version_1_6_16rc03 Your_png_h_is_not_version_1_6_16rc03;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index ed876f7e0..43cd5d4dd 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.16rc02 - December 21, 2014
+libpng version 1.6.16rc03 - December 21, 2014
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index b65a2b2aa..734410875 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.16rc02 - December 21, 2014
+ * libpng version 1.6.16rc03 - December 21, 2014
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 7bd671c07..dc58b689c 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.6.16rc02 - December 21, 2014
+Makefiles for libpng version 1.6.16rc03 - December 21, 2014
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng16.so.16.1.6.16rc02)
+ (gcc, creates libpng16.so.16.1.6.16rc03)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -33,12 +33,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng16.so.16.1.6.16rc02)
+ creates libpng16.so.16.1.6.16rc03)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng16.so.16.1.6.16rc02)
+ creates libpng16.so.16.1.6.16rc03)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng16.so.16.1.6.16rc02)
+ creates libpng16.so.16.1.6.16rc03)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/def.c b/scripts/def.c
index d1734c9e1..40baf7201 100644
--- a/scripts/def.c
+++ b/scripts/def.c
@@ -21,7 +21,7 @@ PNG_DFN "OS2 DESCRIPTION "PNG image compression library""
PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
PNG_DFN ""
PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.6.16rc02"
+PNG_DFN ";Version 1.6.16rc03"
#define PNG_EXPORTA(ordinal, type, name, args, attributes)\
PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 567d7510a..c835442e0 100644
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.6.16rc02
+version=1.6.16rc03
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 64a5607fb..620fd186e 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng16
Name: libpng
Description: Loads and saves PNG files
-Version: 1.6.16rc02
+Version: 1.6.16rc03
Libs: -L${libdir} -lpng16
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 07701ce44..0692afe78 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng16
LIB= png16
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.6.16rc02
+SHLIB_MINOR= 1.6.16rc03
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index df1788da4..94d2be211 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.16rc02
+SHLIB_MINOR= 1.6.16rc03
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index a1683bece..3ea08ad34 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.16rc02
+SHLIB_MINOR= 1.6.16rc03
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 8908a3cb1..8ae5faf90 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,8 +1,8 @@
-/* libpng 1.6.16rc02 STANDARD API DEFINITION */
+/* libpng 1.6.16rc03 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.16rc02 - December 21, 2014 */
+/* Libpng version 1.6.16rc03 - December 21, 2014 */
/* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index f68f0d20a..9f3d9f026 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.6.16rc02
+;Version 1.6.16rc03
;--------------------------------------------------------------
; LIBPNG symbol list as a Win32 DEF file
; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index 32d99ffe3..86d19b317 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.16rc02, December 21, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.16rc02, December 21, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -242,7 +242,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.16rc02, December 21, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -360,7 +360,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.16rc02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -422,9 +422,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.16rc02"
+#define PNG_LIBPNG_VER_STRING "1.6.16rc03"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.16rc02 - December 21, 2014\n"
+ " libpng version 1.6.16rc03 - December 21, 2014\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -438,7 +438,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 02
+#define PNG_LIBPNG_VER_BUILD 03
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -568,7 +568,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_16rc02;
+typedef char* png_libpng_version_1_6_16rc03;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.16rc02, December 21, 2014
+ * libpng version 1.6.16rc03, December 21, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.16rc02, December 21, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.16rc03, December 21, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -242,7 +242,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.16rc02, December 21, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.16rc03, December 21, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -360,7 +360,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.16rc02 are Y2K compliant. It is my belief that
+ * upward through 1.6.16rc03 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*